Struct Generic

pub struct Generic<F, E = Error>
where F: AsFd,
{ pub interest: Interest, pub mode: Mode, /* private fields */ }
Available on crate feature wayland and Linux only.
A generic event source wrapping a FD-backed type

Fields

interest: Interest

The programmed interest

mode: Mode

The programmed mode

Implementations



impl<F> Generic<F>
where F: AsFd,

pub fn new(file: F, interest: Interest, mode: Mode) -> Generic<F>

Wrap a FD-backed type into a Generic event source that uses std::io::Error as its error type.

pub fn new_with_error<E>( file: F, interest: Interest, mode: Mode, ) -> Generic<F, E>

Wrap a FD-backed type into a Generic event source using an arbitrary error type.



impl<F, E> Generic<F, E>
where F: AsFd,

pub fn unwrap(self) -> F

Unwrap the Generic source to retrieve the underlying type

pub fn get_ref(&self) -> &F

Get a reference to the underlying type.

pub unsafe fn get_mut(&mut self) -> &mut F

Get a mutable reference to the underlying type.

Safety

This is unsafe because it allows you to modify the underlying type, which allows you to drop the underlying event source. Dropping the underlying source leads to a dangling reference.