Struct Generic
pub struct Generic<F, E = Error>where
F: AsFd,{
pub interest: Interest,
pub mode: Mode,
/* private fields */
}Available on crate feature
wayland and Linux only.Expand description
A generic event source wrapping a FD-backed type
Fields
interest: InterestThe programmed interest
mode: ModeThe programmed mode
Implementations
impl<F> Generic<F>where
F: AsFd,
impl<F> Generic<F>where
F: AsFd,
pub fn new(file: F, interest: Interest, mode: Mode) -> Generic<F>
pub fn new(file: F, interest: Interest, mode: Mode) -> Generic<F>
Wrap a FD-backed type into a Generic event source that uses
std::io::Error as its error type.
pub fn new_with_error<E>(
file: F,
interest: Interest,
mode: Mode,
) -> Generic<F, E>
pub fn new_with_error<E>( file: F, interest: Interest, mode: Mode, ) -> Generic<F, E>
Wrap a FD-backed type into a Generic event source using an arbitrary error type.